@@ -971,6 +971,15 @@ class TaskGroupAction(AbstractModel):
         :param ActionType: 动作类型：平台、自定义
 注意：此字段可能返回 null，表示取不到有效值。
         :type ActionType: str
+        :param IsExecuteRedo: 是否可重试
+注意：此字段可能返回 null，表示取不到有效值。
+        :type IsExecuteRedo: bool
+        :param ActionRisk: 动作风险级别
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ActionRisk: str
+        :param TaskGroupActionExecuteTime: 动作运行时间
+注意：此字段可能返回 null，表示取不到有效值。
+        :type TaskGroupActionExecuteTime: int
         """
         self.TaskGroupActionId = None
         self.TaskGroupInstances = None
@@ -989,6 +998,9 @@ class TaskGroupAction(AbstractModel):
         self.ActionApiType = None
         self.ActionAttribute = None
         self.ActionType = None
+        self.IsExecuteRedo = None
+        self.ActionRisk = None
+        self.TaskGroupActionExecuteTime = None
 
 
     def _deserialize(self, params):
@@ -1014,6 +1026,9 @@ class TaskGroupAction(AbstractModel):
         self.ActionApiType = params.get("ActionApiType")
         self.ActionAttribute = params.get("ActionAttribute")
         self.ActionType = params.get("ActionType")
+        self.IsExecuteRedo = params.get("IsExecuteRedo")
+        self.ActionRisk = params.get("ActionRisk")
+        self.TaskGroupActionExecuteTime = params.get("TaskGroupActionExecuteTime")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1129,6 +1144,12 @@ class TaskGroupInstance(AbstractModel):
         :param TaskGroupInstanceEndTime: 执行结束时间
 注意：此字段可能返回 null，表示取不到有效值。
         :type TaskGroupInstanceEndTime: str
+        :param TaskGroupInstanceIsRedo: 实例是否可重试
+注意：此字段可能返回 null，表示取不到有效值。
+        :type TaskGroupInstanceIsRedo: bool
+        :param TaskGroupInstanceExecuteTime: 动作实例执行时间
+注意：此字段可能返回 null，表示取不到有效值。
+        :type TaskGroupInstanceExecuteTime: int
         """
         self.TaskGroupInstanceId = None
         self.TaskGroupInstanceObjectId = None
@@ -1139,6 +1160,8 @@ class TaskGroupInstance(AbstractModel):
         self.TaskGroupInstanceStatusType = None
         self.TaskGroupInstanceStartTime = None
         self.TaskGroupInstanceEndTime = None
+        self.TaskGroupInstanceIsRedo = None
+        self.TaskGroupInstanceExecuteTime = None
 
 
     def _deserialize(self, params):
@@ -1151,6 +1174,8 @@ class TaskGroupInstance(AbstractModel):
         self.TaskGroupInstanceStatusType = params.get("TaskGroupInstanceStatusType")
         self.TaskGroupInstanceStartTime = params.get("TaskGroupInstanceStartTime")
         self.TaskGroupInstanceEndTime = params.get("TaskGroupInstanceEndTime")
+        self.TaskGroupInstanceIsRedo = params.get("TaskGroupInstanceIsRedo")
+        self.TaskGroupInstanceExecuteTime = params.get("TaskGroupInstanceExecuteTime")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1182,6 +1207,12 @@ class TaskListItem(AbstractModel):
         :type TaskCreateTime: str
         :param TaskUpdateTime: 任务更新时间
         :type TaskUpdateTime: str
+        :param TaskPreCheckStatus: 0--未开始，1--进行中，2--已完成
+注意：此字段可能返回 null，表示取不到有效值。
+        :type TaskPreCheckStatus: int
+        :param TaskPreCheckSuccess: 环境检查是否通过
+注意：此字段可能返回 null，表示取不到有效值。
+        :type TaskPreCheckSuccess: bool
         """
         self.TaskId = None
         self.TaskTitle = None
@@ -1190,6 +1221,8 @@ class TaskListItem(AbstractModel):
         self.TaskStatus = None
         self.TaskCreateTime = None
         self.TaskUpdateTime = None
+        self.TaskPreCheckStatus = None
+        self.TaskPreCheckSuccess = None
 
 
     def _deserialize(self, params):
@@ -1200,6 +1233,8 @@ class TaskListItem(AbstractModel):
         self.TaskStatus = params.get("TaskStatus")
         self.TaskCreateTime = params.get("TaskCreateTime")
         self.TaskUpdateTime = params.get("TaskUpdateTime")
+        self.TaskPreCheckStatus = params.get("TaskPreCheckStatus")
+        self.TaskPreCheckSuccess = params.get("TaskPreCheckSuccess")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
