@@ -17,6 +17,12 @@
 # CAM签名/鉴权错误。
 AUTHFAILURE = 'AuthFailure'
 
+# 企业认证失败。
+AUTHFAILURE_ENTERPRISE = 'AuthFailure.Enterprise'
+
+# 个人认证失败。
+AUTHFAILURE_PERSONAL = 'AuthFailure.Personal'
+
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
@@ -37,3 +43,6 @@ MISSINGPARAMETER = 'MissingParameter'
 
 # 操作被拒绝。
 OPERATIONDENIED = 'OperationDenied'
+
+# 请求的次数超过了频率限制。
+REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'
