@@ -1206,10 +1206,14 @@ class MetricData(AbstractModel):
         :type Metric: str
         :param DataSet: 表数据
         :type DataSet: list of DatePoint
+        :param MetricCount: 查询范围内的请求总量
+注意：此字段可能返回 null，表示取不到有效值。
+        :type MetricCount: int
         """
         self.Resource = None
         self.Metric = None
         self.DataSet = None
+        self.MetricCount = None
 
 
     def _deserialize(self, params):
@@ -1221,6 +1225,7 @@ class MetricData(AbstractModel):
                 obj = DatePoint()
                 obj._deserialize(item)
                 self.DataSet.append(obj)
+        self.MetricCount = params.get("MetricCount")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1433,6 +1438,67 @@ class ModifyPrivateZoneVpcResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class ModifyRecordsStatusRequest(AbstractModel):
+    """ModifyRecordsStatus请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ZoneId: 私有域ID
+        :type ZoneId: str
+        :param RecordIds: 解析记录ID列表
+        :type RecordIds: list of int
+        :param Status: enabled：生效，disabled：失效
+        :type Status: str
+        """
+        self.ZoneId = None
+        self.RecordIds = None
+        self.Status = None
+
+
+    def _deserialize(self, params):
+        self.ZoneId = params.get("ZoneId")
+        self.RecordIds = params.get("RecordIds")
+        self.Status = params.get("Status")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class ModifyRecordsStatusResponse(AbstractModel):
+    """ModifyRecordsStatus返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ZoneId: 私有域ID
+        :type ZoneId: str
+        :param RecordIds: 解析记录ID列表
+        :type RecordIds: list of int
+        :param Status: enabled：生效，disabled：失效
+        :type Status: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.ZoneId = None
+        self.RecordIds = None
+        self.Status = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.ZoneId = params.get("ZoneId")
+        self.RecordIds = params.get("RecordIds")
+        self.Status = params.get("Status")
+        self.RequestId = params.get("RequestId")
+
+
 class PrivateDNSAccount(AbstractModel):
     """私有域解析账号
 
